@@ -7,7 +7,6 @@ import copy
 import logging
 import os
 import re
-import six
 
 from builtins import bytes
 from caffe2.proto import caffe2_pb2
@@ -16,6 +15,7 @@ from caffe2.python import core, workspace
 from .proto.graph_pb2 import GraphDef
 from .proto.node_def_pb2 import NodeDef
 from .proto.tensor_shape_pb2 import TensorShapeProto
+logger = logging.getLogger(__name__)
 
 
 def _make_unique_name(seen, name, min_version=0):
@@ -165,7 +165,7 @@ def _remap_keys(old_dict, rename_fn):
         None. Modifies old_dict in-place.
     '''
     new_dict = {rename_fn(key): value for key,
-                value in six.iteritems(old_dict)}
+                value in old_dict.items()}
     old_dict.clear()
     old_dict.update(new_dict)
 
@@ -753,7 +753,7 @@ def _try_get_shapes(nets):
         shapes, _ = workspace.InferShapesAndTypes(nets)
         return shapes
     except Exception as e:
-        logging.warning('Failed to compute shapes: %s', e)
+        logger.warning('Failed to compute shapes: %s', e)
         return {}
 
 
